@@ -23,7 +23,7 @@ from .. import env
 
 
 def __get_exists_file(file: str):
-    """查找目录优先级: support.py目录 > Project跟目录 > HUB目录(~/.winwin_hub) > USER目录(~)"""
+    """查找目录优先级: support.py目录 > Project跟目录(./) > HUB目录(~/.winwin_hub) > USER目录(~)"""
     dirs = [os.path.dirname(os.path.abspath(__file__)), env.PROJECT_HOME, env.HUB_HOME, env.USER_HOME]
     for _dir in dirs:
         filepath = os.path.join(_dir, file)
@@ -31,9 +31,11 @@ def __get_exists_file(file: str):
             return filepath
 
 
-# 文件目录、项目跟目录、HOME环境目录, 加载.env环境文件
+# support.py目录、项目跟目录、HUB环境目录、USER目录, 加载.env环境文件
 env_file = __get_exists_file('.env')
 env_file and __load_dotenv(env_file)
+
+
 # logging.info("current env file path is:[%s]" % env_file)
 
 
